==> arrow-instances-free-0.8.1-sources.jar: extension/arrow/free/instances/yoneda/functor/YonedaFunctorInstance.kt <==
package arrow.free.instances.yoneda.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.ForYoneda
import arrow.free.Yoneda
import arrow.free.Yoneda.Companion
import arrow.free.instances.YonedaFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.map(arg1: Function1<A, B>): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@map.map<A, B>(arg1) as arrow.free.Yoneda<U, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.Yoneda<U, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForYoneda, U>, A>, Kind<Kind<ForYoneda, U>, B>> = arrow.free.Yoneda
   .functor<U>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForYoneda, U>, A>, arrow.Kind<arrow.Kind<arrow.free.ForYoneda, U>, B>>

@JvmName("void")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A> Kind<Kind<ForYoneda, U>, A>.void(): Yoneda<U, Unit> = arrow.free.Yoneda.functor<U>().run {
  this@void.void<A>() as arrow.free.Yoneda<U, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.fproduct(arg1: Function1<A, B>): Yoneda<U, Tuple2<A, B>> = arrow.free.Yoneda.functor<U>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.Yoneda<U, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.`as`(arg1: B): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.Yoneda<U, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.tupleLeft(arg1: B): Yoneda<U, Tuple2<B, A>> = arrow.free.Yoneda.functor<U>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.Yoneda<U, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.tupleRight(arg1: B): Yoneda<U, Tuple2<A, B>> = arrow.free.Yoneda.functor<U>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.Yoneda<U, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, B, A : B> Kind<Kind<ForYoneda, U>, A>.widen(): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@widen.widen<B, A>() as arrow.free.Yoneda<U, B>
}

fun <U> Companion.functor(): YonedaFunctorInstance<U> = object : arrow.free.instances.YonedaFunctorInstance<U> {  }

==> arrow-instances-free-0.8.2-sources.jar: extension/arrow/free/instances/yoneda/functor/YonedaFunctorInstance.kt <==
package arrow.free.instances.yoneda.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.ForYoneda
import arrow.free.Yoneda
import arrow.free.Yoneda.Companion
import arrow.free.instances.YonedaFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.map(arg1: Function1<A, B>): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@map.map<A, B>(arg1) as arrow.free.Yoneda<U, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.Yoneda<U, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForYoneda, U>, A>, Kind<Kind<ForYoneda, U>, B>> = arrow.free.Yoneda
   .functor<U>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForYoneda, U>, A>, arrow.Kind<arrow.Kind<arrow.free.ForYoneda, U>, B>>

@JvmName("unit")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A> Kind<Kind<ForYoneda, U>, A>.unit(): Yoneda<U, Unit> = arrow.free.Yoneda.functor<U>().run {
  this@unit.unit<A>() as arrow.free.Yoneda<U, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.fproduct(arg1: Function1<A, B>): Yoneda<U, Tuple2<A, B>> = arrow.free.Yoneda.functor<U>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.Yoneda<U, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.`as`(arg1: B): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.Yoneda<U, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.tupleLeft(arg1: B): Yoneda<U, Tuple2<B, A>> = arrow.free.Yoneda.functor<U>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.Yoneda<U, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, A, B> Kind<Kind<ForYoneda, U>, A>.tupleRight(arg1: B): Yoneda<U, Tuple2<A, B>> = arrow.free.Yoneda.functor<U>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.Yoneda<U, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <U, B, A : B> Kind<Kind<ForYoneda, U>, A>.widen(): Yoneda<U, B> = arrow.free.Yoneda.functor<U>().run {
  this@widen.widen<B, A>() as arrow.free.Yoneda<U, B>
}

fun <U> Companion.functor(): YonedaFunctorInstance<U> = object : arrow.free.instances.YonedaFunctorInstance<U> {  }
